@@ -59,6 +59,7 @@
 #include <time.h>
 #include <ctype.h>
 #include <signal.h>
+#include <stdbool.h>
 #include "beep.h"
 
 #define FREQUENCY	800.0
@@ -80,32 +81,32 @@ static float    intra_char_time;
 static float    inter_char_time;
 static float    inter_word_time;
 static float    catchup_time;
-static int      showletters = 0;
-static int      showmorse = 0;
-static int      wordsbefore = 0;
-static int      wordsafter = 0;
-static int      fancyending = 1;
-static int      noticebad = 0;
-static int      testing = 0;
-static int      showtesting = 0;
+static bool     showletters = false;
+static bool     showmorse = false;
+static bool     wordsbefore = false;
+static bool     wordsafter = false;
+static bool     fancyending = true;
+static bool     noticebad = false;
+static bool     testing = false;
+static bool     showtesting = false;
 static int      keepquiet = 0;
-static int      dynamicspeed = 0;
-static int      charbychar = 0;
-static int	international = 0;
-static int	allprosigns = 0;
-static int	allpunctuation = 0;
+static bool     dynamicspeed = false;
+static bool     charbychar = false;
+static bool	international = false;
+static bool	allprosigns = false;
+static bool	allpunctuation = false;
 static int      tryagaincount = 1;
 static float    words_per_minute = WORDS_PER_MINUTE;
 static float	error_frequency = ERROR_FREQUENCY;
 static float	error_volume = ERROR_VOLUME;
 static float    fwords_per_minute;
-static int      randomletters = 0;
+static bool     randomletters = false;
 #define LETMESEE 2
-static int      typeaway = 0;
+static bool     typeaway = 0;
 
 static int      totalhitcount = 0;
 static int      totalmisscount = 0;
-static int      helpmeflag = 0;
+static bool     helpmeflag = false;
 
 #define MAXWORDLEN	20
 #define TESTBUFSZ ((MAXWORDLEN+1)*10)
@@ -262,10 +263,7 @@ extern char    *optarg;
 extern int      optind;
 int             ch;
 char           *p;
-int             ii, jj;
-int             firsttime, notdoneyet;
-int             yourchar;
-float           randexp, randnum;
+int             ii;
 struct sigaction handler;
 
     if (argc == 1 && isatty (fileno (stdin)))
@@ -351,116 +349,116 @@ struct sigaction handler;
 	switch ((char) ch)
 	{
 	case 'A':
-	    international = 1;
+	    international = true;
 	    break;
 	case 'B':
-	    allpunctuation = 1;
+	    allpunctuation = true;
 	    break;
 	case 'C':
 	    user_charset = optarg;
 	    break;
 	case 'E':
-	    testing = 1;
-	    sscanf (optarg, "%d", &error_threshold);
+	    testing = true;
+	    error_threshold = atoi (optarg);
 	    if (error_threshold < error_floor)
 		error_floor = error_threshold;
 	    break;
 	case 'F':
-	    sscanf (optarg, "%f", &fwords_per_minute);
+	    fwords_per_minute = atof (optarg);
 	    break;
 	case 'I':
 	    typeaway = LETMESEE;
 	    break;
 	case 'M':
-	    testing = 1;
-	    sscanf (optarg, "%d", &max_behindness);
+	    testing = true;
+	    max_behindness = atoi (optarg);
 	    if (max_behindness < 1)
 		max_behindness = 0;
 	    break;
 	case 'N':
-	    sscanf (optarg, "%d", &wordcount);
+	    wordcount = atoi(optarg);
 	    if (wordcount < 1) wordcount = -1;
 	    break;
 	case 'R':
-	    sscanf (optarg, "%d", &timeout);
+	    timeout = atoi (optarg);
 	    timeout *= 60;
 	    if (timeout < 1) timeout = -1;
 	    break;
 	case 'S':
-	    allprosigns = 1;
+	    allprosigns = true;
 	    break;
 	case 'T':
-	    testing = 1;
-	    showtesting = 1;
+	    testing = true;
+	    showtesting = true;
 	    break;
 	case 'X':
-	    sscanf (optarg, "%f", &error_volume);
+	    error_volume = atof (optarg);
 	    break;
 	case 'a':
-	    wordsafter = 1;
+	    wordsafter = true;
 	    break;
 	case 'b':
-	    wordsbefore = 1;
+	    wordsbefore = true;
 	    break;
 	case 'c':
-	    noticebad = 1;
+	    noticebad = true;
 	    break;
 	case 'd':
-	    dynamicspeed = 1;
+	    dynamicspeed = true;
 	    break;
 	case 'e':
-	    fancyending = 0;
+	    fancyending = false;
 	    break;
 	case 'f':
-	    sscanf (optarg, "%f", &frequency1);
+	    frequency1 = atof (optarg);
 	    break;
 	case 'g':
-	    sscanf (optarg, "%f", &frequency2);
+	    frequency2 = atof (optarg);
 	    break;
 	case 'i':
-	    typeaway = 1;
+	    typeaway = true;
 	    break;
 	case 'l':
-	    showletters = 1;
+	    showletters = true;
 	    break;
 	case 'm':
-	    showmorse = 1;
+	    showmorse = true;
 	    break;
 	case 'n':
-	    sscanf (optarg, "%d", &wordlen);
+	    wordlen = atoi (optarg);
 	    if (wordlen < 1) wordlen = 1;
 	    if (wordlen > MAXWORDLEN) wordlen = MAXWORDLEN;
 	    break;
 	case 'p':
-	    charbychar = 1;
-	    testing = 1;
-	    sscanf (optarg, "%d", &tryagaincount);
+	    charbychar = true;
+	    testing = true;
+	    tryagaincount = atoi (optarg);
 	    break;
 	case 'q':
 	    keepquiet = 1;
 	    break;
 	case 'r':
-	    randomletters = 1;
+	    randomletters = true;
 	    break;
 	case 's':
-	    charbychar = 1;
-	    testing = 1;
+	    charbychar = true;
+	    testing = true;
 	    break;
 	case 't':
-	    testing = 1;
+	    testing = true;
 	    break;
 	case 'v':
-	    sscanf (optarg, "%f", &volume);
+	    volume = atof (optarg);
 	    if (volume < 0.)
 		volume = 0.;
 	    if (volume > 1.)
 		volume = 1.;
 	    break;
 	case 'w':
-	    sscanf (optarg, "%f", &words_per_minute);
+	    words_per_minute = atof (optarg);
 	    break;
 	case 'x':
-	    sscanf (optarg, "%f", &error_frequency);
+	    error_frequency = atof (optarg);
 	    break;
 	default:
 	    fprintf (stderr, "Type \"morse\" without arguments to get self-doc!\n");
@@ -647,28 +645,34 @@ struct sigaction handler;
 
     if (typeaway)
     {
-	testing = 0;
-	showtesting = 0;
+	bool notdoneyet;
+
+	testing = false;
+	showtesting = false;
 	charbychar = 0;
 	wordsbefore = 0;
 	wordsafter = 0;
 	randomletters = 0;
 
-	notdoneyet = 1;
+	notdoneyet = true;
 
 	while (notdoneyet)
 	{
+	    int jj;
+
 	    pollyou ();
 
 	    for (jj = 0; jj < yourlength; jj++)
 	    {
+		int             yourchar;
+
 		yourchar = yourstring[(yourpointer - yourlength + 1 + jj + TESTBUFSZ) % TESTBUFSZ];
 
 		/* Control-D: finished */
 		if (yourchar == (int) '\004')
 		{
 		    toneflush ();
-		    notdoneyet = 0;
+		    notdoneyet = false;
 		    break;
 		}
 
@@ -697,6 +701,8 @@ struct sigaction handler;
     }
     else if (randomletters)
     {
+	float           randexp, randnum;
+
 	srand48(time (NULL));
 	randexp = 1. / (1. - 1. / (float) (RANDWORDLEN));
 	while (1)
@@ -722,7 +728,9 @@ struct sigaction handler;
     {
 	if (*argv)
 	{
-	    firsttime = 1;
+	    bool             firsttime;
+
+	    firsttime = true;
 
 	    do
 	    {
@@ -731,7 +739,7 @@ struct sigaction handler;
 		    dowords ((int) ' ');
 		}
 		else
-		    firsttime = 0;
+		    firsttime = false;
 
 		if ((wordcount == 0) || timeout == 0) break;
 
@@ -840,9 +848,6 @@ dowords (int c)
 static int      wordc = 0;
 static char     word[MAXWORDLEN+1];
 char           *wordp;
-int             ii;
-int             againcount = 0;
-int             are_we_repeating;
 
 /*
  * Increment the line position counter.
@@ -856,6 +861,8 @@ int             are_we_repeating;
     {
 	if (wordc > 0)
 	{
+	    int againcount;
+
 	    if (wordcount > 0) wordcount--;
 	    if (timeout > 0)
 	      if (difftime(time(NULL),starttime) > (double)timeout)
@@ -918,7 +925,7 @@ int             are_we_repeating;
 		pollyou ();
 
 		/* Forget the past */
-		helpmeflag = 0;
+		helpmeflag = false;
 		behindness = 0;
 		testlength = 0;
 		yourlength = 0;
@@ -955,6 +962,8 @@ int             are_we_repeating;
 
 		if (showmorse || showletters || wordsafter || showtesting)
 		{
+		    int             ii;
+
 		    printf ("  ");
 		    for (ii = 0; ii < 16 - (wordc + 2); ii++)
 		    {
@@ -1079,7 +1088,8 @@ int             are_we_repeating;
 			 */
 			if (max_behindness > 0)
 			{
-			    are_we_repeating = 0;
+			    bool             are_we_repeating = false;
+
 			    while (behindness >= max_behindness)
 			    {
 #ifdef DEBUG
@@ -1095,7 +1105,7 @@ int             are_we_repeating;
 				}
 				else
 				{
-				    are_we_repeating = 1;
+				    are_we_repeating = true;
 				}
 				/* Finish playing whatever we're playing */
 				toneflush ();
@@ -1436,8 +1446,6 @@ pollyou (void)
 static int
 testterminal (void)
 {
-int             testinc, yourinc;
-int             correctchar, yourchar, yourcharnocase;
 int             errorcount;
 int             resync;
 
@@ -1459,10 +1467,14 @@ int             resync;
  */
     if (yourlength > 0 && testlength > 0)
     {
+	int             testinc, yourinc;
+
 	for (testinc = 0, yourinc = 0;
 	     testinc < testlength && yourinc < yourlength;
 	     testinc++, yourinc++)
 	{
+	    int             correctchar, yourchar, yourcharnocase;
+
 	    correctchar = teststring[(testpointer - testlength + 1 + testinc + TESTBUFSZ) % TESTBUFSZ];
 
 	    /*
@@ -1508,7 +1520,7 @@ int             resync;
 		}
 		else if (yourchar == '\b')
 		{
-		    helpmeflag = 1;
+		    helpmeflag = true;
 		}
 
 		/* The _other_ pointer wasn't used; don't increment it. */
@@ -1887,8 +1899,6 @@ rancomp (const void *elem1, const void *elem2)
 static void
 report (void)
 {
-    int ii, jj, count;
-    float sum; 
     int randomstr[TWOFIFTYSIX];
 
     printf ("\nCurrent words per minute: %.1f\n", words_per_minute);
@@ -1901,6 +1911,9 @@ report (void)
 
     if (randomletters)
     {
+	int ii, jj, count;
+	float sum; 
+
 	printf ("Most to least frequent choices:\n");
 	count = 0;
 	sum = 0.;
